==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/de/messagestyles.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>MessageStyles</name>
    <message>
        <source>Message Styles</source>
        <translation>Nachrichten Stile</translation>
    </message>
    <message>
        <source>d MMM yyyy hh:mm</source>
        <translation>t MMM jjjj hh:mm</translation>
    </message>
    <message>
        <source>d MMM hh:mm</source>
        <translation>t MMM hh:mm</translation>
    </message>
    <message>
        <source>hh:mm:ss</source>
        <translation>hh:mm:ss</translation>
    </message>
    <message>
        <source>Message Styles Manager</source>
        <translation>Nachrichten Stil Manager</translation>
    </message>
    <message>
        <source>Allows to use different styles to display messages</source>
        <translation>Erlaubt das Benutzen von verschiedenen Stile für die Nachrichtenanzeige</translation>
    </message>
</context>
<context>
    <name>StyleOptionsWidget</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Conference</source>
        <translation>Konferenz</translation>
    </message>
    <message>
        <source>The message with a error code %1 is received</source>
        <translation>Die Nachricht wurde mit dem Fehlercode %1 erhalten</translation>
    </message>
    <message>
        <source>Error description</source>
        <translation>Fehler Beschreibung</translation>
    </message>
    <message>
        <source>Subject: Message subject</source>
        <translation>Betreff: Nachrichten Betreff</translation>
    </message>
    <message>
        <source>Message body line 1</source>
        <translation>Nachrichten Body Zeile 1</translation>
    </message>
    <message>
        <source>Message body line 2</source>
        <translation>Nachrichten Body Zeile 2</translation>
    </message>
    <message>
        <source>Incoming history message</source>
        <translation>Eingehende Verlaufs Nachricht</translation>
    </message>
    <message>
        <source>Incoming history consecutive message</source>
        <translation>Eingehene fortlaufende Verlaufs Nachricht</translation>
    </message>
    <message>
        <source>Incoming status message</source>
        <translation>Eingehende Status Nachricht</translation>
    </message>
    <message>
        <source>Outgoing history message</source>
        <translation>Ausgehende Verlaufs Nachricht</translation>
    </message>
    <message>
        <source>Outgoing status message</source>
        <translation>Ausgehende Status Nachricht</translation>
    </message>
    <message>
        <source>Groupchat topic</source>
        <translation>Gruppenchat Thema</translation>
    </message>
    <message>
        <source>Incoming message</source>
        <translation>Eingehende Nachricht</translation>
    </message>
    <message>
        <source>Incoming event</source>
        <translation>Eingehendes Ereignis</translation>
    </message>
    <message>
        <source>Incoming notification</source>
        <translation>Eingehender Hinweis</translation>
    </message>
    <message>
        <source>Incoming mention message</source>
        <translation>Eingehende Erwähnung</translation>
    </message>
    <message>
        <source>Outgoing message</source>
        <translation>Ausgehende Nachricht</translation>
    </message>
    <message>
        <source>Outgoing consecutive message</source>
        <translation>Ausgehende fortlaufende Nachricht</translation>
    </message>
    <message>
        <source>Receiver</source>
        <translation>Empfänger</translation>
    </message>
    <message>
        <source>Sender</source>
        <translation>Sender</translation>
    </message>
    <message>
        <source>Single</source>
        <translation></translation>
    </message>
    <message>
        <source>Headline</source>
        <translation></translation>
    </message>
    <message>
        <source>Error</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>StyleOptionsWidgetClass</name>
    <message>
        <source>Message type:</source>
        <translation>Nachrichten Typ:</translation>
    </message>
    <message>
        <source>Style engine:</source>
        <translation>Stilengine:</translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/de/messagestyles.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>MessageStyles</name>
    <message>
        <source>Message Styles</source>
        <translation>Nachrichten Stile</translation>
    </message>
    <message>
        <source>d MMM yyyy hh:mm</source>
        <translation>d MMM jjjj hh:mm</translation>
    </message>
    <message>
        <source>d MMM hh:mm</source>
        <translation>d MMM hh:mm</translation>
    </message>
    <message>
        <source>hh:mm:ss</source>
        <translation>hh:mm:ss</translation>
    </message>
    <message>
        <source>Message Styles Manager</source>
        <translation>Nachrichten Stil Manager</translation>
    </message>
    <message>
        <source>Allows to use different styles to display messages</source>
        <translation>Erlaubt die Benutzung verschiedener Stile für die Nachrichtenanzeige</translation>
    </message>
    <message>
        <source>Show date separators in chat window</source>
        <translation>Zeige Datums Seperatoren in Chat Fenstern</translation>
    </message>
    <message>
        <source>January</source>
        <translation>Januar</translation>
    </message>
    <message>
        <source>February</source>
        <translation>Februar</translation>
    </message>
    <message>
        <source>March</source>
        <translation>März</translation>
    </message>
    <message>
        <source>April</source>
        <translation>April</translation>
    </message>
    <message>
        <source>May</source>
        <translation>Mai</translation>
    </message>
    <message>
        <source>June</source>
        <translation>Juni</translation>
    </message>
    <message>
        <source>July</source>
        <translation>Juli</translation>
    </message>
    <message>
        <source>August</source>
        <translation>August</translation>
    </message>
    <message>
        <source>September</source>
        <translation>September</translation>
    </message>
    <message>
        <source>October</source>
        <translation>Oktober</translation>
    </message>
    <message>
        <source>November</source>
        <translation>November</translation>
    </message>
    <message>
        <source>December</source>
        <translation>Dezember</translation>
    </message>
    <message>
        <source>Monday</source>
        <translation>Montag</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <translation>Dienstag</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <translation>Mittwoch</translation>
    </message>
    <message>
        <source>Thursday</source>
        <translation>Donnerstag</translation>
    </message>
    <message>
        <source>Friday</source>
        <translation>Freitag</translation>
    </message>
    <message>
        <source>Saturday</source>
        <translation>Samstag</translation>
    </message>
    <message>
        <source>Sunday</source>
        <translation>Sonntag</translation>
    </message>
    <message>
        <source>%1, %2 dd</source>
        <translation>%1, %2 dd</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Heute</translation>
    </message>
    <message>
        <source>%1, %2 dd, yyyy</source>
        <translation>%1 %2 dd, yyyy</translation>
    </message>
</context>
<context>
    <name>StyleOptionsWidget</name>
    <message>
        <source>Chat</source>
        <translation>Chat</translation>
    </message>
    <message>
        <source>Conference</source>
        <translation>Konferenz</translation>
    </message>
    <message>
        <source>The message with a error code %1 is received</source>
        <translation>Die Nachricht wurde mit dem Fehlercode %1 erhalten</translation>
    </message>
    <message>
        <source>Error description</source>
        <translation>Fehler Beschreibung</translation>
    </message>
    <message>
        <source>Subject: Message subject</source>
        <translation>Betreff: Nachrichten Betreff</translation>
    </message>
    <message>
        <source>Message body line 1</source>
        <translation>Nachrichten Body Zeile 1</translation>
    </message>
    <message>
        <source>Message body line 2</source>
        <translation>Nachrichten Body Zeile 2</translation>
    </message>
    <message>
        <source>Incoming history message</source>
        <translation>Eingehende Verlaufs Nachricht</translation>
    </message>
    <message>
        <source>Incoming history consecutive message</source>
        <translation>Eingehene fortlaufende Verlaufs Nachricht</translation>
    </message>
    <message>
        <source>Incoming status message</source>
        <translation>Eingehende Status Nachricht</translation>
    </message>
    <message>
        <source>Outgoing history message</source>
        <translation>Ausgehende Verlaufs Nachricht</translation>
    </message>
    <message>
        <source>Outgoing status message</source>
        <translation>Ausgehende Status Nachricht</translation>
    </message>
    <message>
        <source>Groupchat topic</source>
        <translation>Gruppenchat Thema</translation>
    </message>
    <message>
        <source>Incoming message</source>
        <translation>Eingehende Nachricht</translation>
    </message>
    <message>
        <source>Incoming event</source>
        <translation>Eingehendes Ereignis</translation>
    </message>
    <message>
        <source>Incoming notification</source>
        <translation>Eingehender Hinweis</translation>
    </message>
    <message>
        <source>Incoming mention message</source>
        <translation>Eingehende Erwähnung</translation>
    </message>
    <message>
        <source>Outgoing message</source>
        <translation>Ausgehende Nachricht</translation>
    </message>
    <message>
        <source>Outgoing consecutive message</source>
        <translation>Ausgehende fortlaufende Nachricht</translation>
    </message>
    <message>
        <source>Receiver</source>
        <translation>Empfänger</translation>
    </message>
    <message>
        <source>Sender</source>
        <translation>Sender</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Einzelne Nachricht</translation>
    </message>
    <message>
        <source>Headline</source>
        <translation>Überschrift</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
</context>
<context>
    <name>StyleOptionsWidgetClass</name>
    <message>
        <source>Message type:</source>
        <translation>Nachrichten Typ:</translation>
    </message>
    <message>
        <source>Style engine:</source>
        <translation>Stilengine:</translation>
    </message>
</context>
</TS>
